@@ -5,6 +5,12 @@
 @CREATED    : June 2001 (Rick Hoge)
 @MODIFIED   : 
  * $Log: dcm2mnc.c,v $
+ * Revision 1.24  2010-11-23 23:30:50  claude
+ * dcm2mnc: fixed seg fault bug (Claude) and added b-matrix (Ilana)
+ *
+ * Revision 1.23  2008-08-12 05:00:23  rotor
+ *  * large number of changes from Claude (64 bit and updates)
+ *
  * Revision 1.22  2008/01/17 02:33:01  rotor
  *  * removed all rcsids
  *  * removed a bunch of ^L's that somehow crept in
@@ -577,6 +583,7 @@ free_list(int num_files,
             free((void *) file_list[i]);
         }
         if (file_info_list[i] != NULL) {
+            free(file_info_list[i]->file_name);
             free(file_info_list[i]);
         }
     }
@@ -895,6 +902,7 @@ use_the_files(int num_files,
    
     /* Free acquisition file list */
     free(acq_file_list);
+    free(acq_file_index);
     free(used_file);
 
 }
@@ -926,7 +934,7 @@ static int
 is_ima_file(const char *fullname)
 {
     FILE *fp;
-    char mfg_str[IMA_MAGIC_SIZE];
+    char mfg_str[IMA_MAGIC_SIZE+1];
     int result = 0;
 
     if ((fp = fopen(fullname, "rb")) == NULL) {
