@@ -14,6 +14,13 @@
 @CREATED    : August 28, 1992 (Peter Neelin)
 @MODIFIED   : 
  * $Log: minc_basic.h,v $
+ * Revision 6.8  2010-03-27 15:09:28  rotor
+ *  * back to 1000000
+ *
+ * Revision 6.7  2010-03-02 12:23:14  rotor
+ *  * ported HDF calls to 1.8.x
+ *  * Makefile.am: updated for minccmp
+ *
  * Revision 6.6  2008/04/11 05:15:00  rotor
  *  * rewrote error code  (Claude) to remove global defs that were
  *     causing build problems with DYLIB on OSX
@@ -70,7 +77,7 @@
               make no representations about the suitability of this
               software for any purpose.  It is provided "as is" without
               express or implied warranty.
-@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_basic.h,v 6.6 2008/04/11 05:15:00 rotor Exp $ MINC (MNI)
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc_basic.h,v 6.8 2010-03-27 15:09:28 rotor Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 #include <minc.h>
