@@ -52,31 +52,33 @@
      LEN = 268,
      MAX = 269,
      MIN = 270,
-     ISNAN = 271,
-     SQRT = 272,
-     ABS = 273,
-     EXP = 274,
-     LOG = 275,
-     SIN = 276,
-     COS = 277,
-     TAN = 278,
-     ASIN = 279,
-     ACOS = 280,
-     ATAN = 281,
-     CLAMP = 282,
-     SEGMENT = 283,
-     LT = 284,
-     LE = 285,
-     GT = 286,
-     GE = 287,
-     EQ = 288,
-     NE = 289,
-     NOT = 290,
-     AND = 291,
-     OR = 292,
-     IF = 293,
-     ELSE = 294,
-     FOR = 295
+     IMAX = 271,
+     IMIN = 272,
+     ISNAN = 273,
+     SQRT = 274,
+     ABS = 275,
+     EXP = 276,
+     LOG = 277,
+     SIN = 278,
+     COS = 279,
+     TAN = 280,
+     ASIN = 281,
+     ACOS = 282,
+     ATAN = 283,
+     CLAMP = 284,
+     SEGMENT = 285,
+     LT = 286,
+     LE = 287,
+     GT = 288,
+     GE = 289,
+     EQ = 290,
+     NE = 291,
+     NOT = 292,
+     AND = 293,
+     OR = 294,
+     IF = 295,
+     ELSE = 296,
+     FOR = 297
    };
 #endif
 /* Tokens.  */
@@ -93,31 +95,33 @@
 #define LEN 268
 #define MAX 269
 #define MIN 270
-#define ISNAN 271
-#define SQRT 272
-#define ABS 273
-#define EXP 274
-#define LOG 275
-#define SIN 276
-#define COS 277
-#define TAN 278
-#define ASIN 279
-#define ACOS 280
-#define ATAN 281
-#define CLAMP 282
-#define SEGMENT 283
-#define LT 284
-#define LE 285
-#define GT 286
-#define GE 287
-#define EQ 288
-#define NE 289
-#define NOT 290
-#define AND 291
-#define OR 292
-#define IF 293
-#define ELSE 294
-#define FOR 295
+#define IMAX 271
+#define IMIN 272
+#define ISNAN 273
+#define SQRT 274
+#define ABS 275
+#define EXP 276
+#define LOG 277
+#define SIN 278
+#define COS 279
+#define TAN 280
+#define ASIN 281
+#define ACOS 282
+#define ATAN 283
+#define CLAMP 284
+#define SEGMENT 285
+#define LT 286
+#define LE 287
+#define GT 288
+#define GE 289
+#define EQ 290
+#define NE 291
+#define NOT 292
+#define AND 293
+#define OR 294
+#define IF 295
+#define ELSE 296
+#define FOR 297
 
 
 
@@ -137,7 +141,7 @@ ident_t  ident;
 
 
 /* Line 1676 of yacc.c  */
-#line 141 "progs/minccalc/gram.h"
+#line 145 "progs/minccalc/gram.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
