@@ -121,6 +121,7 @@ Mon May 21 01:01:01 EST 2000 - Original version "imgcalc" by David Leonard
 #include <voxel_loop.h>
 #include <time_stamp.h>
 #include "node.h"
+#include "read_file_names.h"
 
 /* Constants */
 
@@ -143,7 +144,6 @@ static void do_math(void *caller_data, long num_voxels,
                     int input_vector_length, double *input_data[],
                     int output_num_buffers, int output_vector_length,
                     double *output_data[], Loop_Info *loop_info);
-static char **read_file_names(char *filelist, int *num_files);
 static char *read_expression_file(char *filename);
 static int get_list_option(char *dst, char *key, int argc, char **argv);
 
@@ -162,7 +162,7 @@ int propagate_nan = TRUE;
 static int check_dim_info = TRUE;
 static int copy_all_header = DEFAULT_BOOL;
 static int use_nan_for_illegal_values = TRUE;
-static int max_buffer_size_in_kb = 4 * 1024;
+static int max_buffer_size_in_kb = 0;
 static double valid_range[2] = {0.0, 0.0};
 double value_for_illegal_operations = DEFAULT_DBL;
 static nc_type datatype = MI_ORIGINAL_TYPE;
@@ -412,7 +412,12 @@ int main(int argc, char *argv[]){
    set_loop_datatype(loop_options, datatype, is_signed, 
                      valid_range[0], valid_range[1]);
    set_loop_copy_all_header(loop_options, copy_all_header);
-   set_loop_buffer_size(loop_options, (long) 1024 * max_buffer_size_in_kb);
+   
+   /* only set buffer size if specified */
+   if(max_buffer_size_in_kb != 0){
+      set_loop_buffer_size(loop_options, (long) 1024 * max_buffer_size_in_kb);
+      }
+   
    set_loop_check_dim_info(loop_options, check_dim_info);
    voxel_loop(nfiles, infiles, nout, outfiles, arg_string, loop_options,
               do_math, NULL);
@@ -515,93 +520,6 @@ static void do_math(void *caller_data, long num_voxels,
    return;
 }
 
-/* ----------------------------- MNI Header -----------------------------------
-@NAME       : read_file_names
-@INPUT      : filelist - name of file from which to read names
-@OUTPUT     : num_files - number of files read in
-@RETURNS    : Pointer to a NULL-terminated array of file names
-@DESCRIPTION: Reads in a list of file names from file filelist or stdin if 
-              "-" is specified. Returns NULL if an error occurs. If
-              no error occurs, then a pointer to an empty array is 
-              returned and num_files is zero.
-@METHOD     : 
-@GLOBALS    : 
-@CALLS      : 
-@CREATED    : March 8, 1995 (Peter Neelin)
-@MODIFIED   : 
----------------------------------------------------------------------------- */
-static char **read_file_names(char *filelist, int *num_files)
-{
-#define FILE_NAME_ALLOC_SIZE 10
-   char **files;
-   int array_size;
-   int nfiles;
-   FILE *fp;
-   char line[PATH_MAX+1];
-   int length;
-
-   /* Open the file */
-   if (strcmp(filelist, "-") == 0) {
-      fp = stdin;
-   }
-   else {
-      fp = fopen(filelist, "r");
-      if (fp == NULL) {
-         (void) fprintf(stderr, "Error opening file \"%s\"\n", filelist);
-         return NULL;
-      }
-   }
-
-   /* Allocate an initial array and NULL-terminate it */
-   array_size = FILE_NAME_ALLOC_SIZE;
-   files = malloc(sizeof(*files) * array_size);
-   if (files == NULL) {
-      (void) fprintf(stderr, "Error allocating memory\n");
-      return NULL;
-   }
-   nfiles = 0;
-   files[nfiles] = NULL;
-
-   /* Read in file names */
-   while (fgets(line, sizeof(line)/sizeof(line[0]), fp) != NULL) {
-
-      /* Remove a trailing newline and check that there is a name */
-      length = strlen(line);
-      if ((length > 0) && (line[length-1] == '\n')) {
-         line[length-1] = '\0';
-         length--;
-      }
-      if (length == 0) continue;
-
-      /* Make room for names if needed */
-      while (nfiles >= array_size-1) {
-         array_size += FILE_NAME_ALLOC_SIZE;
-         files = realloc(files, sizeof(*files) * array_size);
-         if (files == NULL) {
-            (void) fprintf(stderr, "Error allocating memory\n");
-            return NULL;
-         }
-      }
-
-      /* Save the name, making sure that the list is NULL-terminated */
-      files[nfiles] = strdup(line);
-      if (files[nfiles] == NULL) {
-         (void) fprintf(stderr, "Error allocating memory\n");
-         return NULL;
-      }
-      nfiles++;
-      files[nfiles] = NULL;
-   }
-
-   /* Close the file */
-   (void) fclose(fp);
-
-   /* Return the number of files */
-   *num_files = nfiles;
-
-   return files;
-}
-
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : read_expression_file
 @INPUT      : filename - Name of file from which to read expression
