@@ -10,6 +10,18 @@
 @CREATED    : June 10, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincextract.c,v $
+ * Revision 6.9  2008-01-17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.8  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.7  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 6.6  2006/05/19 00:35:58  bert
  * Add config.h to several files that might need it
  *
@@ -90,10 +102,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincextract/mincextract.c,v 6.6 2006/05/19 00:35:58 bert Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -129,18 +137,18 @@ static nc_type nc_type_list[8] = {
 static int get_arg_vector(char *dst, char *key, char *nextArg);
 
 /* Variables used for argument parsing */
-int arg_odatatype = TYPE_ASCII;
-nc_type output_datatype = NC_DOUBLE;
-int output_signed = INT_MAX;
-double valid_range[2] = {DBL_MAX, DBL_MAX};
-int normalize_output = TRUE;
-double image_range[2] = {DBL_MAX, DBL_MAX};
-long hs_start[MAX_VAR_DIMS] = {LONG_MIN};
-long hs_count[MAX_VAR_DIMS] = {LONG_MIN};
-int xdirection = INT_MAX;
-int ydirection = INT_MAX;
-int zdirection = INT_MAX;
-int default_direction = INT_MAX;
+static int arg_odatatype = TYPE_ASCII;
+static nc_type output_datatype = NC_DOUBLE;
+static int output_signed = INT_MAX;
+static double valid_range[2] = {DBL_MAX, DBL_MAX};
+static int normalize_output = TRUE;
+static double image_range[2] = {DBL_MAX, DBL_MAX};
+static long hs_start[MAX_VAR_DIMS] = {LONG_MIN};
+static long hs_count[MAX_VAR_DIMS] = {LONG_MIN};
+static int xdirection = INT_MAX;
+static int ydirection = INT_MAX;
+static int zdirection = INT_MAX;
+static int default_direction = INT_MAX;
 
 /* Argument table */
 ArgvInfo argTable[] = {
