@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,11 +54,95 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
+/* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
+#line 9 "ncgentab.y"
+
+#ifndef lint
+static char SccsId[] __attribute__ ((unused)) = "$Id: ncgentab.y,v 1.3 2008-01-13 06:49:41 stever Exp $";
+#endif
+#include        <string.h>
+#include	<stdlib.h>
+#include	<minc.h>
+#include 	"generic.h"
+#include        "ncgen.h"
+#include	"genlib.h"	/* for grow_darray() et al */
+
+typedef struct Symbol {		/* symbol table entry */
+	char    	*name;
+	struct Symbol   *next;
+	unsigned	is_dim : 1;	/* appears as netCDF dimension */
+	unsigned	is_var : 1;	/* appears as netCDF variable */
+	unsigned	is_att : 1;	/* appears as netCDF attribute */
+	int             dnum;	        /* handle as a dimension */
+	int             vnum;	        /* handle as a variable */
+	} *YYSTYPE1;
+
+#define YYSTYPE YYSTYPE1
+YYSTYPE symlist;		/* symbol table: linked list */
+
+extern int derror_count;	/* counts errors in netcdf definition */
+extern int lineno;		/* line number for error messages */
+
+static int not_a_string;	/* whether last constant read was a string */
+char termstring[MAXTRST];       /* last terminal string read */
+double double_val;              /* last double value read */
+float float_val;		/* last float value read */
+int int_val;                    /* last int value read */
+short short_val;		/* last short value read */
+static char char_val;		/* last char value read */
+signed char byte_val;           /* last byte value read */
+
+static nc_type type_code;	/* holds declared type for variables */
+static nc_type atype_code;	/* holds derived type for attributes */
+char *netcdfname;               /* to construct netcdf file name */
+static void *att_space;		/* pointer to block for attribute values */
+static nc_type valtype;		/* type code for list of attribute values  */
+
+static char *char_valp;		/* pointers used to accumulate data values */
+static signed char *byte_valp;
+static short *short_valp;
+static int *int_valp;
+static float *float_valp;
+static double *double_valp;
+static void *rec_cur;		/* pointer to where next data value goes */
+static void *rec_start;		/* start of space for data */
+
+
+/* Line 189 of yacc.c  */
+#line 126 "progs/mincgen/ncgentab.c"
+
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+
+/* Enabling verbose error messages.  */
+#ifdef YYERROR_VERBOSE
+# undef YYERROR_VERBOSE
+# define YYERROR_VERBOSE 1
+#else
+# define YYERROR_VERBOSE 0
+#endif
+
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
+
 /* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
@@ -115,92 +198,19 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 9 "ncgentab.y"
-
-#ifndef lint
-static char SccsId[] __attribute__ ((unused)) = "$Id: ncgentab.y,v 1.3 2008/01/13 06:49:41 stever Exp $";
-#endif
-#include        <string.h>
-#include	<stdlib.h>
-#include	<minc.h>
-#include 	"generic.h"
-#include        "ncgen.h"
-#include	"genlib.h"	/* for grow_darray() et al */
-
-typedef struct Symbol {		/* symbol table entry */
-	char    	*name;
-	struct Symbol   *next;
-	unsigned	is_dim : 1;	/* appears as netCDF dimension */
-	unsigned	is_var : 1;	/* appears as netCDF variable */
-	unsigned	is_att : 1;	/* appears as netCDF attribute */
-	int             dnum;	        /* handle as a dimension */
-	int             vnum;	        /* handle as a variable */
-	} *YYSTYPE1;
-
-#define YYSTYPE YYSTYPE1
-YYSTYPE symlist;		/* symbol table: linked list */
-
-extern int derror_count;	/* counts errors in netcdf definition */
-extern int lineno;		/* line number for error messages */
-
-static int not_a_string;	/* whether last constant read was a string */
-char termstring[MAXTRST];       /* last terminal string read */
-double double_val;              /* last double value read */
-float float_val;		/* last float value read */
-int int_val;                    /* last int value read */
-short short_val;		/* last short value read */
-static char char_val;		/* last char value read */
-signed char byte_val;           /* last byte value read */
-
-static nc_type type_code;	/* holds declared type for variables */
-static nc_type atype_code;	/* holds derived type for attributes */
-char *netcdfname;               /* to construct netcdf file name */
-static void *att_space;		/* pointer to block for attribute values */
-static nc_type valtype;		/* type code for list of attribute values  */
-
-static char *char_valp;		/* pointers used to accumulate data values */
-static signed char *byte_valp;
-static short *short_valp;
-static int *int_valp;
-static float *float_valp;
-static double *double_valp;
-static void *rec_cur;		/* pointer to where next data value goes */
-static void *rec_start;		/* start of space for data */
-
-
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
-/* Enabling verbose error messages.  */
-#ifdef YYERROR_VERBOSE
-# undef YYERROR_VERBOSE
-# define YYERROR_VERBOSE 1
-#else
-# define YYERROR_VERBOSE 0
-#endif
-
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef int YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 204 "progs/mincgen/ncgentab.c"
+/* Line 264 of yacc.c  */
+#line 214 "progs/mincgen/ncgentab.c"
 
 #ifdef short
 # undef short
@@ -275,14 +285,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -363,9 +373,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -399,12 +409,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -531,12 +541,13 @@ static const char *const yytname[] =
   "BYTE_CONST", "CHAR_CONST", "SHORT_CONST", "INT_CONST", "FLOAT_CONST",
   "DOUBLE_CONST", "DIMENSIONS", "VARIABLES", "NETCDF", "HDF5", "DATA",
   "FILLVALUE", "'{'", "'}'", "';'", "','", "'='", "'('", "')'", "':'",
-  "$accept", "ncdesc", "@1", "@2", "@3", "@4", "dimsection", "dimdecls",
-  "dimdecline", "dimdecl", "dimd", "dim", "vasection", "vadecls", "vadecl",
-  "gattdecls", "gattdecl", "vardecl", "type", "varlist", "varspec", "@5",
-  "var", "dimspec", "dimlist", "vdim", "attdecl", "@6", "att", "avar",
-  "attr", "attvallist", "aconst", "attconst", "datasection", "datadecls",
-  "datadecl", "@7", "constlist", "dconst", "@8", "const", 0
+  "$accept", "ncdesc", "$@1", "$@2", "$@3", "$@4", "dimsection",
+  "dimdecls", "dimdecline", "dimdecl", "dimd", "dim", "vasection",
+  "vadecls", "vadecl", "gattdecls", "gattdecl", "vardecl", "type",
+  "varlist", "varspec", "$@5", "var", "dimspec", "dimlist", "vdim",
+  "attdecl", "$@6", "att", "avar", "attr", "attvallist", "aconst",
+  "attconst", "datasection", "datadecls", "datadecl", "$@7", "constlist",
+  "dconst", "$@8", "const", 0
 };
 #endif
 
@@ -867,17 +878,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -911,11 +925,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1195,10 +1209,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1214,11 +1226,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1226,9 +1237,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1252,14 +1263,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1267,51 +1303,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1341,7 +1354,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1349,7 +1361,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1372,9 +1383,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1385,7 +1395,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1395,6 +1404,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1403,16 +1415,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1444,20 +1456,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1497,11 +1505,15 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 94 "ncgentab.y"
     { init_netcdf(0); }
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 97 "ncgentab.y"
     {
 		       if (derror_count == 0)
@@ -1510,6 +1522,8 @@ yyreduce:
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 103 "ncgentab.y"
     {
 		       if (derror_count == 0)
@@ -1518,11 +1532,15 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 110 "ncgentab.y"
     { init_netcdf(1); }
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 113 "ncgentab.y"
     {
 		       if (derror_count == 0)
@@ -1531,6 +1549,8 @@ yyreduce:
     break;
 
   case 7:
+
+/* Line 1455 of yacc.c  */
 #line 119 "ncgentab.y"
     {
 		       if (derror_count == 0)
@@ -1539,6 +1559,8 @@ yyreduce:
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 134 "ncgentab.y"
     { if (int_val <= 0)
 			 derror("dimension length must be positive");
@@ -1548,6 +1570,8 @@ yyreduce:
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 140 "ncgentab.y"
     {  if (rec_dim != -1)
 			 derror("only one NC_UNLIMITED dimension allowed");
@@ -1558,6 +1582,8 @@ yyreduce:
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 148 "ncgentab.y"
     { if ((yyvsp[(1) - (1)])->is_dim == 1) {
 		        derror( "duplicate dimension declaration for %s",
@@ -1576,36 +1602,50 @@ yyreduce:
     break;
 
   case 29:
+
+/* Line 1455 of yacc.c  */
 #line 181 "ncgentab.y"
     { type_code = NC_BYTE; }
     break;
 
   case 30:
+
+/* Line 1455 of yacc.c  */
 #line 182 "ncgentab.y"
     { type_code = NC_CHAR; }
     break;
 
   case 31:
+
+/* Line 1455 of yacc.c  */
 #line 183 "ncgentab.y"
     { type_code = NC_SHORT; }
     break;
 
   case 32:
+
+/* Line 1455 of yacc.c  */
 #line 184 "ncgentab.y"
     { type_code = NC_INT; }
     break;
 
   case 33:
+
+/* Line 1455 of yacc.c  */
 #line 185 "ncgentab.y"
     { type_code = NC_FLOAT; }
     break;
 
   case 34:
+
+/* Line 1455 of yacc.c  */
 #line 186 "ncgentab.y"
     { type_code = NC_DOUBLE; }
     break;
 
   case 37:
+
+/* Line 1455 of yacc.c  */
 #line 192 "ncgentab.y"
     {
 		    static struct vars dummyvar;
@@ -1642,6 +1682,8 @@ yyreduce:
     break;
 
   case 38:
+
+/* Line 1455 of yacc.c  */
 #line 225 "ncgentab.y"
     {
 		    vars[nvars].ndims = nvdims;
@@ -1650,6 +1692,8 @@ yyreduce:
     break;
 
   case 44:
+
+/* Line 1455 of yacc.c  */
 #line 239 "ncgentab.y"
     {
 		    if (nvdims >= NC_MAX_VAR_DIMS) {
@@ -1673,6 +1717,8 @@ yyreduce:
     break;
 
   case 45:
+
+/* Line 1455 of yacc.c  */
 #line 260 "ncgentab.y"
     {
 		       valnum = 0;
@@ -1690,6 +1736,8 @@ yyreduce:
     break;
 
   case 46:
+
+/* Line 1455 of yacc.c  */
 #line 274 "ncgentab.y"
     {
 		       {	/* check if duplicate attribute for this var */
@@ -1723,6 +1771,8 @@ yyreduce:
     break;
 
   case 48:
+
+/* Line 1455 of yacc.c  */
 #line 306 "ncgentab.y"
     {
 		    varnum = NC_GLOBAL;  /* handle of "global" attribute */
@@ -1730,6 +1780,8 @@ yyreduce:
     break;
 
   case 49:
+
+/* Line 1455 of yacc.c  */
 #line 312 "ncgentab.y"
     { if ((yyvsp[(1) - (1)])->is_var == 1)
 		       varnum = (yyvsp[(1) - (1)])->vnum;
@@ -1742,6 +1794,8 @@ yyreduce:
     break;
 
   case 50:
+
+/* Line 1455 of yacc.c  */
 #line 322 "ncgentab.y"
     {
 		       /* make sure atts array will hold attributes */
@@ -1755,6 +1809,8 @@ yyreduce:
     break;
 
   case 53:
+
+/* Line 1455 of yacc.c  */
 #line 336 "ncgentab.y"
     {
 		    if (valtype == NC_UNSPECIFIED)
@@ -1765,6 +1821,8 @@ yyreduce:
     break;
 
   case 54:
+
+/* Line 1455 of yacc.c  */
 #line 345 "ncgentab.y"
     {
 		       atype_code = NC_CHAR;
@@ -1774,6 +1832,8 @@ yyreduce:
     break;
 
   case 55:
+
+/* Line 1455 of yacc.c  */
 #line 351 "ncgentab.y"
     {
 		       atype_code = NC_CHAR;
@@ -1790,6 +1850,8 @@ yyreduce:
     break;
 
   case 56:
+
+/* Line 1455 of yacc.c  */
 #line 364 "ncgentab.y"
     {
 		       atype_code = NC_BYTE;
@@ -1799,6 +1861,8 @@ yyreduce:
     break;
 
   case 57:
+
+/* Line 1455 of yacc.c  */
 #line 370 "ncgentab.y"
     {
 		       atype_code = NC_SHORT;
@@ -1808,6 +1872,8 @@ yyreduce:
     break;
 
   case 58:
+
+/* Line 1455 of yacc.c  */
 #line 376 "ncgentab.y"
     {
 		       atype_code = NC_INT;
@@ -1817,6 +1883,8 @@ yyreduce:
     break;
 
   case 59:
+
+/* Line 1455 of yacc.c  */
 #line 382 "ncgentab.y"
     {
 		       atype_code = NC_FLOAT;
@@ -1826,6 +1894,8 @@ yyreduce:
     break;
 
   case 60:
+
+/* Line 1455 of yacc.c  */
 #line 388 "ncgentab.y"
     {
 		       atype_code = NC_DOUBLE;
@@ -1835,6 +1905,8 @@ yyreduce:
     break;
 
   case 65:
+
+/* Line 1455 of yacc.c  */
 #line 403 "ncgentab.y"
     {
 		       valtype = vars[varnum].type; /* variable type */
@@ -1888,6 +1960,8 @@ yyreduce:
     break;
 
   case 66:
+
+/* Line 1455 of yacc.c  */
 #line 453 "ncgentab.y"
     {
 		       if (valnum < var_len) { /* leftovers */
@@ -1905,6 +1979,8 @@ yyreduce:
     break;
 
   case 69:
+
+/* Line 1455 of yacc.c  */
 #line 471 "ncgentab.y"
     {
 		       if(valnum >= var_len) {
@@ -1933,6 +2009,8 @@ yyreduce:
     break;
 
   case 70:
+
+/* Line 1455 of yacc.c  */
 #line 496 "ncgentab.y"
     {
 		       if (not_a_string) {
@@ -1961,6 +2039,8 @@ yyreduce:
     break;
 
   case 71:
+
+/* Line 1455 of yacc.c  */
 #line 523 "ncgentab.y"
     {
 		       atype_code = NC_CHAR;
@@ -1989,6 +2069,8 @@ yyreduce:
     break;
 
   case 72:
+
+/* Line 1455 of yacc.c  */
 #line 548 "ncgentab.y"
     {
 		       not_a_string = 0;
@@ -2046,6 +2128,8 @@ yyreduce:
     break;
 
   case 73:
+
+/* Line 1455 of yacc.c  */
 #line 602 "ncgentab.y"
     {
 		       atype_code = NC_BYTE;
@@ -2074,6 +2158,8 @@ yyreduce:
     break;
 
   case 74:
+
+/* Line 1455 of yacc.c  */
 #line 627 "ncgentab.y"
     {
 		       atype_code = NC_SHORT;
@@ -2102,6 +2188,8 @@ yyreduce:
     break;
 
   case 75:
+
+/* Line 1455 of yacc.c  */
 #line 652 "ncgentab.y"
     {
 		       atype_code = NC_INT;
@@ -2130,6 +2218,8 @@ yyreduce:
     break;
 
   case 76:
+
+/* Line 1455 of yacc.c  */
 #line 677 "ncgentab.y"
     {
 		       atype_code = NC_FLOAT;
@@ -2158,6 +2248,8 @@ yyreduce:
     break;
 
   case 77:
+
+/* Line 1455 of yacc.c  */
 #line 702 "ncgentab.y"
     {
 		       atype_code = NC_DOUBLE;
@@ -2189,6 +2281,8 @@ yyreduce:
     break;
 
   case 78:
+
+/* Line 1455 of yacc.c  */
 #line 730 "ncgentab.y"
     {
 		       /* store fill_value */
@@ -2223,8 +2317,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2228 "progs/mincgen/ncgentab.c"
+
+/* Line 1455 of yacc.c  */
+#line 2323 "progs/mincgen/ncgentab.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2235,7 +2330,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -2300,7 +2394,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2317,7 +2411,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2374,9 +2468,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -2401,7 +2492,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2412,7 +2503,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2438,6 +2529,8 @@ yyreturn:
 }
 
 
+
+/* Line 1675 of yacc.c  */
 #line 764 "ncgentab.y"
 
 
