@@ -410,6 +410,18 @@ static void get_arginfo(int argc, char *argv[],
       {"-znelements", ARGV_LONG, (char *) 0, 
           (char *) &args.volume_def.nelements[Z],
           "Number of elements along the Z dimension"},
+      {"-size", ARGV_LONG, (char *) 3, 
+          (char *) args.volume_def.nelements,
+          "synonym for -nelements)"},
+      {"-xsize", ARGV_LONG, (char *) 0, 
+          (char *) &args.volume_def.nelements[X],
+          "synonym for -xnelements"},
+      {"-ysize", ARGV_LONG, (char *) 0, 
+          (char *) &args.volume_def.nelements[Y],
+          "synonym for -ynelements"},
+      {"-zsize", ARGV_LONG, (char *) 0, 
+          (char *) &args.volume_def.nelements[Z],
+          "synonym for -ynelements"},
       {"-step", ARGV_FLOAT, (char *) 3, 
           (char *) args.volume_def.step,
           "Step size along each dimension (X, Y, Z)"},
