@@ -7,6 +7,12 @@
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincresample.h,v $
+ * Revision 6.8  2008-01-13 09:38:54  stever
+ * Avoid compiler warnings about functions and variables that are defined
+ * but not used.  Remove some such functions and variables,
+ * conditionalize some, and move static declarations out of header files
+ * into C files.
+ *
  * Revision 6.7  2005/07/13 21:34:25  bert
  * Add sinc interpolant (ported from 1.X branch)
  *
@@ -341,73 +347,17 @@ typedef struct {
 
 /* Function prototypes */
 
-static void get_arginfo(int argc, char *argv[],
-                        Program_Flags *program_flags,
-                        VVolume *in_vol, VVolume *out_vol, 
-                        General_transform *transformation);
-static void check_imageminmax(File_Info *fp, Volume_Data *volume);
-static void get_file_info(char *filename, int initialized_volume_def, 
-                          Volume_Definition *volume_def,
-                          File_Info *file_info);
-static void get_args_volume_def(Volume_Definition *input_volume_def,
-                                Volume_Definition *args_volume_def);
-static void transform_volume_def(Transform_Info *transform_info,
-                                 Volume_Definition *input_volume_def,
-                                 Volume_Definition *transformed_volume_def);
-static int is_zero_vector(double vector[]);
-static void normalize_vector(double vector[]);
-static void create_output_file(char *filename, int clobber, 
-                               Volume_Definition *volume_def,
-                               File_Info *in_file,
-                               File_Info *out_file,
-                               char *tm_stamp, 
-                               Transform_Info *transform_info);
-static void get_voxel_to_world_transf(Volume_Definition *volume_def, 
-                                      General_transform *voxel_to_world);
-static void irregular_transform_function(void *user_data,
-                                         Real x,
-                                         Real y,
-                                         Real z,
-                                         Real *x_trans,
-                                         Real *y_trans,
-                                         Real *z_trans);
-static void irregular_inverse_transform_function(void *user_data,
-                                                 Real x,
-                                                 Real y,
-                                                 Real z,
-                                                 Real *x_trans,
-                                                 Real *y_trans,
-                                                 Real *z_trans);
-static double get_default_range(char *what, nc_type datatype, int is_signed);
-static void finish_up(VVolume *in_vol, VVolume *out_vol);
-static int get_transformation(char *dst, char *key, char *nextArg);
-static int get_model_file(char *dst, char *key, char *nextArg);
-static int set_standard_sampling(char *dst, char *key, char *nextArg);
-static int set_spacetype(char *dst, char *key, char *nextArg);
-static int set_units(char *dst, char *key, char *nextArg);
-static int get_axis_order(char *dst, char *key, char *nextArg);
-static int get_fillvalue(char *dst, char *key, char *nextArg);
 extern void resample_volumes(Program_Flags *program_flags,
                              VVolume *in_vol, VVolume *out_vol, 
                              General_transform *transformation);
-static void load_volume(File_Info *file, long start[], long count[], 
-                        Volume_Data *volume);
-static void get_slice(long slice_num, VVolume *in_vol, VVolume *out_vol, 
-                      General_transform *transformation, 
-                      double *minimum, double *maximum);
 extern int trilinear_interpolant(Volume_Data *volume, 
                                  Coord_Vector coord, double *result);
 extern int tricubic_interpolant(Volume_Data *volume, 
                                 Coord_Vector coord, double *result);
-static int do_Ncubic_interpolation(Volume_Data *volume, 
-                                   long index[], int cur_dim, 
-                                   double frac[], double *result);
 extern int nearest_neighbour_interpolant(Volume_Data *volume, 
                                          Coord_Vector coord, double *result);
 extern int windowed_sinc_interpolant(Volume_Data *volume,
                                      Coord_Vector coord, double *result);
-static void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
-                               double slice_min[], double slice_max[]);
 
 #define SINC_HALF_WIDTH_MAX 10
 #define SINC_HALF_WIDTH_MIN 1
