@@ -12,8 +12,11 @@ main(int argc, char **argv)
 {
    int icv, cdfid, img, max, min, dimvar;
    static int dim[MAX_VAR_DIMS];
-   static struct { long len; char *name;} diminfo[]=
-      {3, MIzspace, 9, MIyspace, 2, MIxspace};
+   static struct { long len; char *name;} diminfo[] = { 
+      { 3, MIzspace }, 
+      { 9, MIyspace }, 
+      { 2, MIxspace }
+   };
 /*   static struct { long len; char *name;} diminfo[]=
       {3, MIzspace, 4, MIyspace, 5, MIxspace}; */
    static int numdims=sizeof(diminfo)/sizeof(diminfo[0]);
@@ -34,7 +37,7 @@ main(int argc, char **argv)
       331, 333, 335, 337, 339,
       341, 343, 345, 347, 349
    };
-   int i, j, k, intype, inorm, outtype, imax, ival;
+   int i, j, k;
    int cflag = 0;
 
 #if MINC2
