@@ -2,7 +2,7 @@
 
 set -e
 
-tests=minc_types icv_range icv icv_dim icv_dim1 icv_fillvalue
+tests="minc_types icv_range icv icv_dim icv_dim1 icv_fillvalue"
 
 for test in $tests;
 do
