@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Geometry/gaussian.c,v 1.10 2006/04/19 16:28:19 claude Exp $";
-#endif
-
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : scaled_maximal_pivoting_gaussian_elimination
 @INPUT      : n                 size of matrix, n by n
