@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/MNI_formats/gen_xf_io.c,v 1.23 2004/10/04 20:23:51 bert Exp $";
-#endif
-
 /*--------------------- file format keywords ------------------------------ */
 
 static const STRING      TRANSFORM_FILE_HEADER = "MNI Transform File";
