@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/MNI_formats/mni_io.c,v 1.12 2005/05/18 21:35:51 bert Exp $";
-#endif
-
 static   const char      COMMENT_CHAR1 = '%';
 static   const char      COMMENT_CHAR2 = '#';
 
