@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/MNI_formats/tag_points.c,v 1.23 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 static   const char      *TAG_FILE_HEADER = "MNI Tag Point File";
 static   const char      *VOLUMES_STRING = "Volumes";
 static   const char      *TAG_POINTS_STRING = "Points";
