@@ -13,6 +13,10 @@
 ---------------------------------------------------------------------------- */
 
 #include  <internal_volume_io.h>
+
+#if HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif /* HAVE_SYS_TYPES_H */
 #if HAVE_PWD_H
 #include  <pwd.h>
 #endif /* HAVE_PWD_H */
@@ -20,13 +24,10 @@
 #if HAVE_UNISTD_H
 #include  <unistd.h>
 #endif /* HAVE_UNISTD_H */
+
 #include  <errno.h>
 
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Prog_utils/files.c,v 1.42 2005/05/19 21:19:28 bert Exp $";
-#endif
-
 static  BOOLEAN  has_no_extension( STRING );
 static  STRING   compressed_endings[] = { ".z", ".Z", ".gz" };
 
@@ -537,8 +538,8 @@ VIOAPI  Status  move_file(
 static  STRING  get_user_home_directory(
     STRING   user_name )
 {
-#if HAVE_GETPWNAM
-    struct   passwd  *p;
+#if HAVE_GETPWNAM 
+    struct passwd  *p;
 
     p = getpwnam( user_name );
 
@@ -2520,7 +2521,7 @@ VIOAPI  Status  io_unsigned_char(
         }
         else
         {
-            if( fprintf( file, "%d", (int) *c ) != 1 )
+            if( fprintf( file, " %d", (int) *c ) < 0  )
             {
                 print_error( "Error outputting unsigned char.  " );
                 print_system_error();
