@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Prog_utils/string.c,v 1.10 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 static const  STRING  empty_string = "";
 
 VIOAPI  STRING  alloc_string(
