@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/evaluate.c,v 1.35 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : convert_voxel_to_value
 @INPUT      : volume
@@ -1072,12 +1068,13 @@ VIOAPI  void   evaluate_volume_in_world(
         axis = volume->spatial_axes[d];
         if( axis < 0 )
         {
-            print_error(
-                  "evaluate_volume_in_world(): must have 3 spatial axes.\n" );
-            return;
+          // print_error(
+          //       "evaluate_volume_in_world(): must have 3 spatial axes.\n" );
+          // return;
+        } else {
+          interpolating_dimensions[axis] = TRUE;
         }
 
-        interpolating_dimensions[axis] = TRUE;
     }
 
     /*--- compute the number of values, the product of the sizes of the
