@@ -14,10 +14,6 @@
 
 #include  <internal_volume_io.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/set_hyperslab.c,v 1.3 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 VIOAPI  void  convert_values_to_voxels(
     Volume   volume,
     int      n_voxels,
