@@ -18,7 +18,7 @@
 #define   HASH_TABLE_SIZE_FACTOR          3
 
 #define   DEFAULT_BLOCK_SIZE              64
-#define   DEFAULT_CACHE_THRESHOLD         100000000
+#define   DEFAULT_CACHE_THRESHOLD         -1
 #define   DEFAULT_MAX_BYTES_IN_CACHE      100000000
 
 static  BOOLEAN  n_bytes_cache_threshold_set = FALSE;
@@ -239,7 +239,7 @@ static  void  get_default_cache_block_sizes(
 
         /*--- set the last two dimensions to be entire size of dimension */
 
-        for_less( dim, MAX( 0, n_dims - 2), n_dims )
+        for_less( dim, MAX( 0, n_dims - 2), MAX_DIMENSIONS )
             block_sizes[dim] = -1;
     }
     else if( !default_block_sizes_set &&
